[Updated on OS6] TimerEvent is no longer existing!! Checked TimerEvent function on os5 latest version. Result is okay on FRDM-K64F but STM32 series are NOT okay e.g. Nucleo-L152RE, -F446RE, -L432KC and so on. This TimerEvent is using SoftSerial library and works well on old os2 but not OS5 latest version STM32 series Mbed board.

Forum discussion.
https://forums.mbed.com/t/how-to-port-software-serial-to-os5-6/12641
https://forums.mbed.com/t/softserial-problem-l432kc/8288

Revision:
1:3e3b7ec1f33d
Parent:
0:0a78edc7ac85
--- a/check_revision.cpp	Tue May 12 01:15:04 2020 +0000
+++ b/check_revision.cpp	Tue Mar 30 07:30:39 2021 +0000
@@ -1,23 +1,27 @@
 /*
  * Check Mbed revision
  *
- * Copyright (c) 2020 Kenji Arai / JH1PJL
+ * Copyright (c) 2020,'21 Kenji Arai / JH1PJL
  *  http://www7b.biglobe.ne.jp/~kenjia/
  *  https://os.mbed.com/users/kenjiArai/
  *      Created:    May       12th, 2020
- *      Revised:    May       12th, 2020
+ *      Revised:    March     30th, 2021
  */
+#include "mbed.h"
 
-#include "mbed.h"
- 
+//    RUN ONLY ON mbed-os-6.8.0 or 6.9.0
+//      https://github.com/ARMmbed/mbed-os/releases/tag/mbed-os-6.9.0
+#if (MBED_MAJOR_VERSION == 6) &&\
+    ((MBED_MINOR_VERSION == 8) ||  (MBED_MINOR_VERSION == 9))&&\
+    (MBED_PATCH_VERSION == 0)
 //    RUN ONLY ON mbed-os-5.15.3
 //      https://github.com/ARMmbed/mbed-os/releases/tag/mbed-os-5.15.3
-#if (MBED_MAJOR_VERSION == 5) &&\
+#elif (MBED_MAJOR_VERSION == 5) &&\
     (MBED_MINOR_VERSION == 15) &&\
     (MBED_PATCH_VERSION == 3)
 #elif (MBED_MAJOR_VERSION == 2) &&\
     (MBED_MINOR_VERSION == 0) &&\
-    (MBED_PATCH_VERSION == 132)
+    (MBED_PATCH_VERSION == 162)
 #else
     #error "Please use mbed-os-5.15.3 or mbed-os-2.132"
 #endif
@@ -1,23 +1,27 @@
 #else
-    #error "Please use mbed-os-5.15.3 or mbed-os-2.132"
+    #error "Please use mbed-os-5.15.3 or mbed-os-2.162 or os-6.8.0/6.9.0!"
 #endif